@@ -34,7 +34,7 @@ def backwards(apps, schema_editor):
 class Migration(migrations.Migration):
     atomic = False
 
-    dependencies = [('data_manager', '0007_auto_20220708_0832')]
+    dependencies = [('data_manager', '0007_auto_20220708_0832'), ('projects', '0017_project_pinned_at')]
 
     operations = [
         migrations.RunPython(forwards, backwards),
