@@ -4,12 +4,11 @@ import logging
 import redis
 import json
 
-from django.db import models, transaction
+from django.db import models
 from django.utils.translation import gettext_lazy as _
 from django.dispatch import receiver
 from django.db.models.signals import post_save
 from io_storages.base_models import ImportStorage, ImportStorageLink, ExportStorage, ExportStorageLink
-from io_storages.serializers import StorageAnnotationSerializer
 from tasks.models import Annotation
 
 logger = logging.getLogger(__name__)
@@ -75,6 +74,9 @@ class RedisImportStorage(ImportStorage, RedisStorageMixin):
         _('db'), default=1,
         help_text='Server Database')
 
+    def can_resolve_url(self, url):
+        return False
+
     def iterkeys(self):
         client = self.get_client()
         path = str(self.path)
