@@ -11,8 +11,8 @@ from django.core.validators import MinLengthValidator, MaxLengthValidator
 from django.db import transaction, models
 from annoying.fields import AutoOneToOneField
 
-from core.redis import start_job_async_or_sync
 from data_manager.managers import TaskQuerySet
+from projects.functions.utils import make_queryset_from_iterable
 from tasks.models import Task, Prediction, Annotation, Q_task_finished_annotations, bulk_update_stats_project_tasks
 from core.utils.common import create_hash, get_attr_or_item, load_func
 from core.utils.exceptions import LabelStudioValidationErrorSentryIgnored
@@ -349,9 +349,18 @@ class Project(ProjectMixin, models.Model):
         membership = ProjectMember.objects.filter(user=user, project=self)
         return membership.exists() and membership.first().enabled
 
-    def _update_tasks_states(
-        self, maximum_annotations_changed, overlap_cohort_percentage_changed, tasks_number_changed
-    ):
+    def _update_tasks_states(self,
+                             maximum_annotations_changed,
+                             overlap_cohort_percentage_changed,
+                             tasks_number_changed):
+        """
+        Update tasks states after settings change
+        :param maximum_annotations_changed: If maximum_annotations param changed
+        :param overlap_cohort_percentage_changed: If cohort_percentage param changed
+        :param tasks_number_changed: If tasks number changed in project
+        """
+        logger.info(f"Starting _update_tasks_states with params: Project {str(self)} maximum_annotations "
+                    f"{self.maximum_annotations} and percentage {self.overlap_cohort_percentage}")
         # if only maximum annotations parameter is tweaked
         if maximum_annotations_changed and (not overlap_cohort_percentage_changed or self.maximum_annotations == 1):
             tasks_with_overlap = self.tasks.filter(overlap__gt=1)
@@ -363,6 +372,11 @@ class Project(ProjectMixin, models.Model):
             else:
                 # otherwise affect all tasks
                 self.tasks.update(overlap=self.maximum_annotations)
+                tasks_with_overlap = self.tasks.all()
+            # update is_labeled after change
+            bulk_update_stats_project_tasks(
+                tasks_with_overlap, project=self
+            )
 
         # if cohort slider is tweaked
         elif overlap_cohort_percentage_changed and self.maximum_annotations > 1:
@@ -372,33 +386,6 @@ class Project(ProjectMixin, models.Model):
         elif tasks_number_changed and self.overlap_cohort_percentage < 100 and self.maximum_annotations > 1:
             self._rearrange_overlap_cohort()
 
-        if maximum_annotations_changed or overlap_cohort_percentage_changed or tasks_number_changed:
-            bulk_update_stats_project_tasks(
-                self.tasks.filter(Q(annotations__isnull=False))
-            )
-
-    def update_tasks_states(
-        self, maximum_annotations_changed, overlap_cohort_percentage_changed, tasks_number_changed
-    ):
-        start_job_async_or_sync(self._update_tasks_states, maximum_annotations_changed, overlap_cohort_percentage_changed, tasks_number_changed)
-
-
-    def update_tasks_states_with_counters(
-        self, maximum_annotations_changed, overlap_cohort_percentage_changed,
-            tasks_number_changed, tasks_queryset
-    ):
-        start_job_async_or_sync(self._update_tasks_states_with_counters, maximum_annotations_changed,
-                                overlap_cohort_percentage_changed, tasks_number_changed, tasks_queryset)
-
-
-    def _update_tasks_states_with_counters(
-        self, maximum_annotations_changed, overlap_cohort_percentage_changed,
-            tasks_number_changed, tasks_queryset
-    ):
-        self._update_tasks_states(maximum_annotations_changed, overlap_cohort_percentage_changed,
-            tasks_number_changed)
-        self.update_tasks_counters(tasks_queryset)
-
     def _rearrange_overlap_cohort(self):
         """
         Rearrange overlap depending on annotation count in tasks
@@ -406,7 +393,8 @@ class Project(ProjectMixin, models.Model):
         all_project_tasks = Task.objects.filter(project=self)
         max_annotations = self.maximum_annotations
         must_tasks = int(self.tasks.count() * self.overlap_cohort_percentage / 100 + 0.5)
-
+        logger.info(f"Starting _update_tasks_states with params: Project {str(self)} maximum_annotations "
+                    f"{max_annotations} and percentage {self.overlap_cohort_percentage}")
         tasks_with_max_annotations = all_project_tasks.annotate(
             anno=Count('annotations', filter=Q_task_finished_annotations & Q(annotations__ground_truth=False))
         ).filter(anno__gte=max_annotations)
@@ -414,29 +402,29 @@ class Project(ProjectMixin, models.Model):
         tasks_with_min_annotations = all_project_tasks.exclude(
             id__in=tasks_with_max_annotations
         )
-
         # check how many tasks left to finish
         left_must_tasks = max(must_tasks - tasks_with_max_annotations.count(), 0)
+        logger.info(f"Required tasks {must_tasks} and left required tasks {left_must_tasks}")
         if left_must_tasks > 0:
             # if there are unfinished tasks update tasks with count(annotations) >= overlap
-            tasks_with_max_annotations.update(overlap=max_annotations)
+            tasks_with_max_annotations.update(overlap=max_annotations, is_labeled=True)
             # order other tasks by count(annotations)
             tasks_with_min_annotations = tasks_with_min_annotations.annotate(
                 anno=Count('annotations')
-            ).order_by('-anno')
-            objs = []
+            ).order_by('-anno').distinct()
             # assign overlap depending on annotation count
-            for item in tasks_with_min_annotations[:left_must_tasks]:
-                item.overlap = max_annotations
-                objs.append(item)
-            for item in tasks_with_min_annotations[left_must_tasks:]:
-                item.overlap = 1
-                objs.append(item)
-            with transaction.atomic():
-                bulk_update(objs, update_fields=['overlap'], batch_size=settings.BATCH_SIZE)
+            # assign max_annotations and update is_labeled
+            ids = tasks_with_min_annotations[:left_must_tasks].values_list('id', flat=True)
+            all_project_tasks.filter(id__in=ids).update(overlap=max_annotations)
+            # assign 1 to left
+            ids = tasks_with_min_annotations[left_must_tasks:].values_list('id', flat=True)
+            min_tasks_to_update = all_project_tasks.filter(id__in=ids)
+            min_tasks_to_update.update(overlap=1)
         else:
             tasks_with_max_annotations.update(overlap=max_annotations)
             tasks_with_min_annotations.update(overlap=1)
+        # update is labeled after tasks rearrange overlap
+        bulk_update_stats_project_tasks(all_project_tasks, project=self)
 
     def remove_tasks_by_file_uploads(self, file_upload_ids):
         self.tasks.filter(file_upload_id__in=file_upload_ids).delete()
@@ -520,6 +508,8 @@ class Project(ProjectMixin, models.Model):
             diff_str = []
             for ann_tuple in different_annotations:
                 from_name, to_name, t = ann_tuple.split('|')
+                if t.lower() == 'textarea':  # avoid textarea to_name check (see DEV-1598)
+                    continue
                 if not check_control_in_config_by_regex(config_string, from_name) or \
                 not check_toname_in_config_by_regex(config_string, to_name) or \
                 t not in get_all_types(config_string):
@@ -549,6 +539,10 @@ class Project(ProjectMixin, models.Model):
             labels_from_config_by_tag = set(labels_from_config[get_original_fromname_by_regex(config_string, control_tag_from_data)])
             parsed_config = parse_config(config_string)
             tag_types = [tag_info['type'] for _, tag_info in parsed_config.items()]
+            # DEV-1990 Workaround for Video labels as there are no labels in VideoRectangle tag
+            if 'VideoRectangle' in tag_types:
+                for key in labels_from_config:
+                    labels_from_config_by_tag |= set(labels_from_config[key])
             if 'Taxonomy' in tag_types:
                 custom_tags = Label.objects.filter(links__project=self).values_list('value', flat=True)
                 flat_custom_tags = set([item for sublist in custom_tags for item in sublist])
@@ -561,7 +555,8 @@ class Project(ProjectMixin, models.Model):
                         (not check_control_in_config_by_regex(config_string, control_tag_from_data, filter=dynamic_label_from_config.keys()))):
                     # raise error if labels not dynamic and not in regex rules
                     raise LabelStudioValidationErrorSentryIgnored(
-                        f'These labels still exist in annotations:\n{diff_str}')
+                        f'These labels still exist in annotations:\n{diff_str}.'
+                        f'Please add labels to tag with name="{str(control_tag_from_data)}".')
                 else:
                     logger.info(f'project_id={self.id} inconsistent labels in config and annotations: {diff_str}')
 
@@ -798,7 +793,13 @@ class Project(ProjectMixin, models.Model):
         self._storage_objects = storage_objects
         return storage_objects
 
-    def update_tasks_counters(self, queryset, from_scratch=True):
+    def _update_tasks_counters(self, queryset, from_scratch=True):
+        """
+        Update tasks counters
+        :param queryset: Tasks to update queryset
+        :param from_scratch: Skip calculated tasks
+        :return: Count of updated tasks
+        """
         objs = []
 
         total_annotations = Count("annotations", distinct=True, filter=Q(annotations__was_cancelled=False))
@@ -838,6 +839,32 @@ class Project(ProjectMixin, models.Model):
             bulk_update(objs, update_fields=['total_annotations', 'cancelled_annotations', 'total_predictions'], batch_size=settings.BATCH_SIZE)
         return len(objs)
 
+    def _update_tasks_counters_and_is_labeled(self, queryset, from_scratch=True):
+        """
+        Update tasks counters and is_labeled in a single operation
+        :param queryset: Tasks to update queryset
+        :param from_scratch: Skip calculated tasks
+        :return: Count of updated tasks
+        """
+        queryset = make_queryset_from_iterable(queryset)
+        objs = self._update_tasks_counters(queryset, from_scratch)
+        bulk_update_stats_project_tasks(queryset, self)
+        return objs
+
+    def _update_tasks_counters_and_task_states(self, queryset, maximum_annotations_changed,
+                                               overlap_cohort_percentage_changed, tasks_number_changed,
+                                               from_scratch=True):
+        """
+        Update tasks counters and update tasks states (rearrange and\or is_labeled)
+        :param queryset: Tasks to update queryset
+        :param from_scratch: Skip calculated tasks
+        :return: Count of updated tasks
+        """
+        queryset = make_queryset_from_iterable(queryset)
+        objs = self._update_tasks_counters(queryset, from_scratch)
+        self._update_tasks_states(maximum_annotations_changed, overlap_cohort_percentage_changed, tasks_number_changed)
+        return objs
+
     def __str__(self):
         return f'{self.title} (id={self.id})' or _("Business number %d") % self.pk
 
@@ -1001,6 +1028,9 @@ class ProjectSummary(models.Model):
 
     def _get_labels(self, result):
         result_type = result.get('type')
+        # DEV-1990 Workaround for Video labels as there are no labels in VideoRectangle tag
+        if result_type in ['videorectangle']:
+            result_type = 'labels'
         result_value = result['value'].get(result_type)
         if not result_value or not isinstance(result_value, list) or result_type == 'text':
             # Non-list values are not labels. TextArea list values (texts) are not labels too.
